Package: tirt
Title: Testlet Item Response Theory
Version: 0.4.0
Authors@R: c(
    person("Jiawei", "Xiong", email = "jiawei.xiong@uga.edu", role = c("aut", "cre")),
    person("Cheng", "Tang", role = "ctb"),
    person("Qidi", "Liu", role = "ctb")
  )
Description: Implementation of Testlet and Item Response Theory. 
    A light-version yet comprehensive and streamlined framework for psychometric analysis using 
    unidimensional and multidimensional Item Response Theory 
    (IRT; Baker & Kim (2004) <doi:10.1201/9781482276725>) and Testlet Response Theory 
    (TRT; Wainer et al., (2007) <doi:10.1017/CBO9780511618765>). 
    Designed for researchers, this package supports the estimation of item and person 
    parameters for a wide variety of models, including binary (i.e., Rasch, 2-Parameter Logistic, 3-Parameter Logistic) 
    and polytomous (Partial Credit Model, Generalized Partial Credit Model, Graded Response Model) formats. It also supports the estimation of Testlet models (Rasch Testlet, 2-Parameter Logistic Testlet, 3-Parameter Logistic Testlet, Bifactor, Partial Credit Model Testlet, Graded Response), allowing users to account for local item dependence in bundled items. A key feature is the specialized support for combination use and joint estimation of item response model and testlet response model in one calibration.
    Beyond standard estimation via Marginal Maximum Likelihood with Expectation-Maximization (EM) or Joint Maximum Likelihood, the package also offers Bayesian estimation using priors with maximum a posteriori (MAP) method for unidimensional item response theory models.
    It also provides functions for scale linking and equating (Mean-Mean, Mean-Sigma, Stocking-Lord) to ensure comparability across mixed-format test forms. It also facilitates fixed-parameter calibration, enabling users to estimate person abilities with known item parameters or 
    vice versa, which is essential for pre-equating studies and item bank 
    maintenance. Comprehensive data simulation functions are included to generate 
    synthetic datasets with complex structures, including mixed-model blocks and 
    specific testlet effects, aiding in methodological research and study design
    validation. Researchers can try multiple simulation situations.
    A suite of post-estimation tools is also provided, including item and test
    information functions with the conditional standard error of measurement,
    summed-score to scale-score conversion tables (expected a posteriori, weighted
    likelihood, and maximum likelihood), person-fit and item-fit statistics, local
    dependence diagnostics (Yen's Q3), differential item functioning
    (M-H and logistic regression), reliability coefficients, test
    characteristic curves, and mixture (latent-class) item response models.
License: GPL-3
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: dplyr, tidyr, purrr, gtools, stats, utils
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-08-05 15:36:51 UTC; jx
Author: Jiawei Xiong [aut, cre],
  Cheng Tang [ctb],
  Qidi Liu [ctb]
Maintainer: Jiawei Xiong <jiawei.xiong@uga.edu>
Repository: CRAN
Date/Publication: 2026-08-20 08:10:02 UTC
